=================
MetaSUB Utilities
=================


.. image:: https://img.shields.io/pypi/v/metasub_utils.svg
        :target: https://pypi.python.org/pypi/metasub_utils

.. image:: https://pyup.io/repos/github/dcdanko/metasub_utils/shield.svg
     :target: https://pyup.io/repos/github/dcdanko/metasub_utils/
     :alt: Updates


Utilities for the MetaSUB Consortium


* Free software: MIT license


Features
--------

A collection of utilites to manage the MetaSUB project.

Most of the tools in this package involve uploading or downloading data.

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

